@@ -197,6 +197,22 @@ class RuleManager:
 
         return rule
 
+    def loader(self, rule: Dict[str, Any]):
+        catalog = rule.get("DATABASE_NAME")
+        schema = rule.get("SCHEMA")
+
+        for file_info in rule.get("FILES", []):
+            path = file_info['PATH']
+            delimiter = file_info.get('DELIMITER', '|')
+            header = file_info.get('HEADER', 'true')
+            table_name = file_info['TEMP_TABLE_NAME']
+            qualified_table_name = f"{catalog}.{schema}.{table_name}"
+
+            self.logger.info(f"Loading file into: {qualified_table_name}")
+            df = self.spark.read.option("header", header).option("delimiter", delimiter).option("inferSchema", "true").csv(path)
+            df.write.mode("overwrite").saveAsTable(qualified_table_name)
+
+    
     def set_data_parity_check_templates(self, rule: Dict[str, Any]) -> Dict[str, Any]:
         """Load SQL templates for data parity check based on engine type.
         
@@ -785,6 +801,16 @@ class RuleManager:
 
         return rule
 
+    def drop_temp_tables(self, rule: Dict[str, Any]):
+        catalog = rule.get("DATABASE_NAME")
+        schema = rule.get("SCHEMA")
+
+        for file_info in rule.get("FILES", []):
+            table_name = file_info['TEMP_TABLE_NAME']
+            qualified_table_name = f"{catalog}.{schema}.{table_name}"
+            self.logger.info(f"Dropping temp table: {qualified_table_name}")
+            self.spark.sql(f"DROP TABLE IF EXISTS {qualified_table_name}")
+
 
     def business_rule_check(self) -> Dict[str, List[Dict[str, Any]]]:
         results = []
@@ -835,19 +861,29 @@ class RuleManager:
             for idx, rule in enumerate(self.rules.get("RULES", [])):
                 rule = {**self.template, **rule}
                 rule = self.set_system_variables(rule)
+
+                if rule.get("LOAD_FILES", False):
+                    self.logger.info(f"Loading files for rule: {rule['RULE_NAME']}")
+                    self.loader(rule)  
+
                 rule = self.set_data_parity_check_templates(rule)
                 rule = self.set_bookmark_value(rule)
                 rule = self.set_data_parity_check_final_queries(rule)
                 rule = self.exec_data_parity_check_final_queries(rule)
+
                 self.rules["RULES"][idx] = rule
                 
+                if rule.get("DROP_TEMP_TABLES", False):
+                    self.logger.info(f"Dropping temp tables for rule: {rule['RULE_NAME']}")
+                    self.drop_temp_tables(rule)
+
                 if 'summary_report_df' in rule and not rule['summary_report_df'].empty:
                     print("SUMMARY REPORT:")
                     print(rule['summary_report_df'].to_string())
-                    
-                self.logger.info(f"Rule {idx + 1} processed successfully")
 
-                results.append(self.rules)
+                self.logger.info(f"Rule {idx + 1} processed successfully")
+                results.append(rule)
+
 
         print(json.dumps({"RULES": results}, indent=2))
         return results
\ No newline at end of file
