@@ -37,7 +37,7 @@ FROM (
 
             -- Row match count
             SUM(CASE WHEN
-                <REPEAT_COL_CHECK> md5(cast(SOURCE.<COLUMN_TO_CHECK> AS STRING)) = md5(cast(TARGET.<COLUMN_TO_CHECK> AS STRING)) 
+                <REPEAT_COL_CHECK> md5(coalesce(cast(SOURCE.<COLUMN_TO_CHECK> AS STRING), '__NULL__')) = md5(coalesce(cast(TARGET.<COLUMN_TO_CHECK> AS STRING), '__NULL__'))
                 <NO_COLUMN_TO_CHECK> AND
                 <REPEAT_COL_CHECK> md5(cast(SOURCE.<METRIC_DIM_COL> AS STRING)) = md5(cast(TARGET.<METRIC_DIM_COL> AS STRING)) 
                 <NO_METRIC_DIM_COL> AND 
@@ -56,7 +56,7 @@ FROM (
             END) AS <BOOKMARK_COLUMN_NAME>_matched_count,
 
             -- Individual column match counts
-            <REPEAT> SUM(CASE WHEN md5(trim(cast(SOURCE.<COLUMN_TO_CHECK> AS STRING))) = md5(trim(cast(TARGET.<COLUMN_TO_CHECK> AS STRING))) THEN 1 ELSE 0 END) AS <COLUMN_TO_CHECK>_matched_count,
+            <REPEAT> SUM(CASE WHEN md5(coalesce(trim(cast(SOURCE.<COLUMN_TO_CHECK> AS STRING)), '__NULL__')) = md5(coalesce(trim(cast(TARGET.<COLUMN_TO_CHECK> AS STRING)), '__NULL__')) THEN 1 ELSE 0 END) AS <COLUMN_TO_CHECK>_matched_count,
 
             current_timestamp() AS last_modified_ts
 
@@ -120,7 +120,7 @@ FROM (
             CASE 
                 WHEN TARGET.<BOOKMARK_COLUMN_NAME> IS NULL THEN 'MISSING_IN_TARGET'
                 WHEN NOT (
-                    <REPEAT_COL_CHECK> md5(CAST(SOURCE.<COLUMN_TO_CHECK> AS STRING)) = md5(CAST(TARGET.<COLUMN_TO_CHECK> AS STRING))
+                    <REPEAT_COL_CHECK> md5(coalesce(cast(SOURCE.<COLUMN_TO_CHECK> AS STRING), '__NULL__')) = md5(coalesce(cast(TARGET.<COLUMN_TO_CHECK> AS STRING), '__NULL__'))
                     <NO_COLUMN_TO_CHECK> AND
                     <REPEAT_COL_CHECK> md5(CAST(SOURCE.<METRIC_DIM_COL> AS STRING)) = md5(CAST(TARGET.<METRIC_DIM_COL> AS STRING))
                     <NO_METRIC_DIM_COL> AND
@@ -143,7 +143,7 @@ FROM (
 
             -- Detailed column-by-column mismatch flags
             map( 
-                <REPEAT> '<COLUMN_TO_CHECK>_mismatch', CASE WHEN md5(TRIM(CAST(SOURCE.<COLUMN_TO_CHECK> AS STRING))) != md5(TRIM(CAST(TARGET.<COLUMN_TO_CHECK> AS STRING))) OR SOURCE.<COLUMN_TO_CHECK> IS DISTINCT FROM TARGET.<COLUMN_TO_CHECK> THEN true ELSE false END,
+                <REPEAT> '<COLUMN_TO_CHECK>_mismatch', CASE WHEN md5(coalesce(trim(cast(SOURCE.<COLUMN_TO_CHECK> AS STRING)), '__NULL__')) != md5(coalesce(trim(cast(TARGET.<COLUMN_TO_CHECK> AS STRING)), '__NULL__')) OR SOURCE.<COLUMN_TO_CHECK> IS DISTINCT FROM TARGET.<COLUMN_TO_CHECK> THEN true ELSE false END,
 
                 '<BOOKMARK_COLUMN_NAME>_mismatch',
                 CASE 
@@ -157,7 +157,7 @@ FROM (
             CASE 
                 WHEN TARGET.<BOOKMARK_COLUMN_NAME> IS NULL THEN 'Row missing in target'
                 ELSE trim(BOTH ',' FROM concat(
-                    <REPEAT> CASE WHEN md5(TRIM(CAST(SOURCE.<COLUMN_TO_CHECK> AS STRING))) != md5(TRIM(CAST(TARGET.<COLUMN_TO_CHECK> AS STRING))) OR SOURCE.<COLUMN_TO_CHECK> IS DISTINCT FROM TARGET.<COLUMN_TO_CHECK> THEN '<COLUMN_TO_CHECK>,' ELSE '' END,
+                    <REPEAT> CASE WHEN md5(coalesce(trim(cast(SOURCE.<COLUMN_TO_CHECK> AS STRING)), '__NULL__')) != md5(coalesce(trim(cast(TARGET.<COLUMN_TO_CHECK> AS STRING)), '__NULL__')) OR SOURCE.<COLUMN_TO_CHECK> IS DISTINCT FROM TARGET.<COLUMN_TO_CHECK> THEN '<COLUMN_TO_CHECK>,' ELSE '' END,
                     CASE 
                         WHEN md5(TRIM(CAST(SOURCE.<BOOKMARK_COLUMN_NAME> AS STRING))) != md5(TRIM(CAST(TARGET.<BOOKMARK_COLUMN_NAME> AS STRING)))
                              OR SOURCE.<BOOKMARK_COLUMN_NAME> IS DISTINCT FROM TARGET.<BOOKMARK_COLUMN_NAME>
@@ -178,7 +178,7 @@ FROM (
                 -- Only include rows that have mismatches or are missing in target
                 TARGET.<BOOKMARK_COLUMN_NAME> IS NULL
                 OR NOT (
-                    <REPEAT_COL_CHECK> md5(CAST(SOURCE.<COLUMN_TO_CHECK> AS STRING)) = md5(CAST(TARGET.<COLUMN_TO_CHECK> AS STRING))
+                    <REPEAT_COL_CHECK> md5(coalesce(cast(SOURCE.<COLUMN_TO_CHECK> AS STRING), '__NULL__')) = md5(coalesce(cast(TARGET.<COLUMN_TO_CHECK> AS STRING), '__NULL__'))
                     <NO_COLUMN_TO_CHECK> AND
                     <REPEAT_COL_CHECK> md5(CAST(SOURCE.<METRIC_DIM_COL> AS STRING)) = md5(CAST(TARGET.<METRIC_DIM_COL> AS STRING))
                     <NO_METRIC_DIM_COL> AND
