@@ -1,8 +1,6 @@
-#START <TAGS>
 -- RULE_CATEGORY_NAME:<RULE_CATEGORY_NAME>
 -- TEAM_NAME:<TEAM_NAME>
 -- DOMAIN_NAME:<DOMAIN_NAME>
 -- INVENTORY:<INVENTORY>
 -- RULE_NAME:<RULE_NAME>
 -- UNIQUE_RULE_IDENTIFIER:<UNIQUE_RULE_IDENTIFIER>
-#END <TAGS>
\ No newline at end of file
